package com.thebrokenrail.mtudining.activity.menu;

import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentManager;

import com.google.android.material.datepicker.MaterialDatePicker;
import com.thebrokenrail.mtudining.R;

import java.util.Calendar;
import java.util.Date;
import java.util.TimeZone;

/**
 * Date picker for menu selection.
 */
public class MenuDatePicker {
    private final static String TAG = "menu_date_picker";

    /**
     * Show date picker.
     * @param current Currently selected date
     * @param fragmentManager Support fragment manager
     */
    public static void show(Date current, FragmentManager fragmentManager) {
        // Get Date In UTC
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(current);
        Calendar utcCalendar = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
        copyDateFromCalender(calendar, utcCalendar);
        // Build Picker
        MaterialDatePicker<Long> datePicker = MaterialDatePicker.Builder.datePicker()
            .setTitleText(R.string.select_date)
            .setSelection(utcCalendar.getTimeInMillis())
            .build();
        // Show
        datePicker.show(fragmentManager, TAG);
        // Handle Selection
        setupListeners(datePicker);
    }

    /**
     * Setup event listeners on existing date picker.
     * @param datePicker The date picker
     */
    private static void setupListeners(MaterialDatePicker<Long> datePicker) {
        datePicker.addOnPositiveButtonClickListener(selection -> {
            // Get Selection
            if (selection != null) {
                // Get New Date
                Calendar calendar = Calendar.getInstance();
                Calendar utcCalendar = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
                Date selectedDate = new Date(selection);
                utcCalendar.setTime(selectedDate);
                copyDateFromCalender(utcCalendar, calendar);
                Date newDate = calendar.getTime();
                // Get Activity
                MenuActivity activity = (MenuActivity) datePicker.requireActivity();
                // Update Date
                activity.updateDate(newDate);
            }
        });
    }

    /**
     * Setup event listeners on existing date picker.
     * @param fragmentManager Support fragment manager
     */
    @SuppressWarnings({"unchecked"})
    public static void setupListeners(FragmentManager fragmentManager) {
        // Get Picker
        Fragment fragment = fragmentManager.findFragmentByTag(TAG);
        if (fragment != null) {
            MaterialDatePicker<Long> datePicker = (MaterialDatePicker<Long>) fragment;
            setupListeners(datePicker);
        }
    }

    private static void copyDateFromCalender(Calendar src, Calendar dst) {
        int year = src.get(Calendar.YEAR);
        int month = src.get(Calendar.MONTH);
        int day = src.get(Calendar.DAY_OF_MONTH);
        dst.set(Calendar.YEAR, year);
        dst.set(Calendar.MONTH, month);
        dst.set(Calendar.DAY_OF_MONTH, day);
    }
}
