package com.thebrokenrail.mtudining.api.method;

import com.thebrokenrail.mtudining.api.Method;
import com.thebrokenrail.mtudining.util.Category;
import com.thebrokenrail.mtudining.util.DateUtil;

import java.util.Date;
import java.util.List;

/**
 * API call for retrieving the menu from a "period."
 */
public class PeriodDetail implements Method<PeriodDetail.Response> {
    private final int platform;
    private final String locationId;
    private final String date;
    private final String period;

    public PeriodDetail(int platform, String locationId, Date date, String period) {
        this.platform = platform;
        this.locationId = locationId;
        this.date = DateUtil.toString(date);
        this.period = period;
    }

    @Override
    public String getPath() {
        return "/location/" + locationId + "/periods/" + period + "?platform=" + platform + "&date=" + date;
    }

    @Override
    public Class<Response> getResponseClass() {
        return Response.class;
    }

    public static class Response {
        public static class Menu {
            public static class PeriodData {
                public static class MenuCategory {
                    public static class MenuItem implements Category.Named {
                        public static class Nutrient {
                            public String name;
                            public String value;
                        }

                        public static class Filter {
                            public String name;
                            public String type;
                        }

                        public String name;
                        public String desc;
                        public String ingredients;
                        public String portion;
                        public List<Nutrient> nutrients;
                        public List<Filter> filters;
                        public int sort_order;

                        @Override
                        public String getName() {
                            return name;
                        }
                    }
                    public String name;
                    public List<MenuItem> items;
                    public int sort_order;
                }
                public List<MenuCategory> categories;
            }
            public PeriodData periods;
        }
        public Menu menu;
    }
}
