package com.thebrokenrail.mtudining.widget;

import static android.view.accessibility.AccessibilityEvent.TYPE_VIEW_CLICKED;

import android.annotation.SuppressLint;
import android.content.Context;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.accessibility.AccessibilityEvent;
import android.widget.EditText;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.google.android.material.textfield.TextInputLayout;

/**
 * {@link TextInputLayout} with support for custom dropdown handling.
 */
public class CustomDropDownView extends TextInputLayout {
    public CustomDropDownView(@NonNull Context context, @Nullable AttributeSet attributeSet) {
        super(context, attributeSet);
    }

    /**
     * Current handler.
     */
    private Runnable onDropDown = null;

    /**
     * Set new dropdown handler.
     * @param onDropDown New handler
     */
    public void setOnDropDown(Runnable onDropDown) {
        this.onDropDown = onDropDown;
    }

    @Override
    public void onPopulateAccessibilityEvent(AccessibilityEvent event) {
        super.onPopulateAccessibilityEvent(event);
        // Run Callback
        // https://github.com/material-components/material-components-android/blob/dd8f6bebdd45c2875fab6574376a604a7d40061a/lib/java/com/google/android/material/textfield/DropdownMenuEndIconDelegate.java#L249-L252
        if (event.getEventType() == TYPE_VIEW_CLICKED && onDropDown != null) {
            onDropDown.run();
        }
    }

    /**
     * Setup touch handler.
     */
    @SuppressLint("ClickableViewAccessibility")
    public void setup() {
        EditText editText = getEditText();
        if (editText != null) {
            // https://github.com/material-components/material-components-android/blob/dd8f6bebdd45c2875fab6574376a604a7d40061a/lib/java/com/google/android/material/textfield/DropdownMenuEndIconDelegate.java#L285-L291
            editText.setOnTouchListener((v, event) -> {
                if (event.getAction() == MotionEvent.ACTION_UP && onDropDown != null) {
                    onDropDown.run();
                }
                return false;
            });
        }
    }
}
